Utc

Struct Utc 

pub struct Utc;
The UTC time zone. This is the most efficient time zone when you don’t need the local time. It is also used as an offset (which is also a dummy type).

Using the TimeZone methods on the UTC struct is the preferred way to construct DateTime<Utc> instances.

Example

use chrono::{DateTime, TimeZone, Utc};

let dt = DateTime::from_timestamp(61, 0).unwrap();

assert_eq!(Utc.timestamp_opt(61, 0).unwrap(), dt);
assert_eq!(Utc.with_ymd_and_hms(1970, 1, 1, 0, 1, 1).unwrap(), dt);

Implementations

Source

impl Utc

pub fn today() -> Date<Utc>

👎Deprecated since 0.4.23:

use Utc::now() instead, potentially with .date_naive()

Returns a Date which corresponds to the current date.

pub fn now() -> DateTime<Utc>

Returns a DateTime<Utc> which corresponds to the current date and time in UTC.

See also the similar Local::now() which returns DateTime<Local>, i.e. the local date and time including offset from UTC.

Example
// Current time in UTC
let now_utc = Utc::now();

// Current date in UTC
let today_utc = now_utc.date_naive();

// Current time in some timezone (let's use +05:00)
let offset = FixedOffset::east_opt(5 * 60 * 60).unwrap();
let now_with_offset = Utc::now().with_timezone(&offset);